#
# spec file for package rbac-manager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rbac-manager
Version:        1.9.0
Release:        1.3
Summary:        Kubernetes operator for easier RBAC management
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/FairwindsOps/rbac-manager
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.22

# test dependency
BuildRequires:  git-core

ExcludeArch:    s390
ExcludeArch:    %{ix86}

%description
RBAC Manager is designed to simplify authorization in Kubernetes.

This is an operator that supports declarative configuration for RBAC with new
custom resources.

Instead of managing role bindings or service accounts directly, you can specify
a desired state and RBAC Manager will make the necessary changes to achieve
that state.

%package k8s-yaml
Summary:        Kubernetes yaml file to run rbac-manager
Group:          System/Management
BuildArch:      noarch

%description k8s-yaml
This package contains the yaml file requried to download and run the
rbac-manager in a kubernetes cluster.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/fairwindsops/rbac-manager/version.Version=v%{version}" \
   -o bin/%{name} ./cmd/manager/

%check
go test ./...

%install
mkdir -p %{buildroot}%{_sbindir}/
install -D -m 0755 bin/%{name} %{buildroot}%{_sbindir}/%{name}

# Install provided yaml file to download and run the rbac-manager
mkdir -p %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/0_namespace.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/1_rbac.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/2_crd.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
install -m 0644 deploy/3_deployment.yaml %{buildroot}%{_datadir}/k8s-yaml/rbac-manager
sed -i -e 's|image: "quay.io/reactiveops/rbac-manager:.*|image: "kubic/rbac-manager:%{version}"|g' %{buildroot}%{_datadir}/k8s-yaml/rbac-manager/3_deployment.yaml

%files
%license LICENSE
%doc docs/* examples
%{_sbindir}/rbac-manager

%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%{_datarootdir}/k8s-yaml/rbac-manager

%changelog
* Wed Oct  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- replace "make test" with just calling "go test ./..." as no
  golangci-lint is available
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.0:
  * ci: add cosign yes flag
  * docs: fix dead link
  * Sudermanjr/update deps and golang (#477)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  * Update documentation from template (#433)
  * sc/pkg bumps 2023 12 15 (#442)
  * Bump alpine from 3.18 to 3.19 (#439)
  * Managed by Terraform
  * test(e2e): test on later versions of k8s (#441)
  * test: add chainsaw tests (#438)
  * Update modules with go mod tidy (#427)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.0:
  * Allow extra manually added pull secrets to managed SA (#418)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.5:
  * Bump github.com/prometheus/client_golang from 1.15.1 to 1.16.0
    (#404)
  * Bump k8s.io/client-go from 0.27.2 to 0.27.3 (#402)
  * fix: add inline struct tag (#401)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.4:
  * remove auto-generated README and fix HTML (#400)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.3:
  * fix documentation site
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.2:
  * Update logo to current (#399)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.1:
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.4 (#397)
  * Bump github.com/sirupsen/logrus from 1.9.2 to 1.9.3 (#398)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.0:
  * update deps and alpine version (#390)
  * Bump alpine from 3.17 to 3.18 (#389)
  * Bump github.com/stretchr/testify from 1.8.0 to 1.8.2 (#371)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.5.0:
  * Update dependencies and docker image (#382)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.4.3:
  * Update documentation from template (#372)
  * Fix circleci builds (#377)
  * Update documentation from template (#362)
* Mon Nov 28 2022 alexandre.vicenzi@suse.com
- Update to version 1.4.2:
  * Updated dependencies
  * Fix helm syntax (#325)
  * Support automountServiceAccountToken in Service Accounts (#324)
  * Allow empty subjects list (#323)
  * Fix an issue where we don't return errors (#322)
* Fri Mar 25 2022 alexandre.vicenzi@suse.com
- Update to version 1.1.0:
  * Update documentation
  * Bugfixes
* Fri Apr  9 2021 alexandre.vicenzi@suse.com
- Update to version 0.10.0:
  * Update dependencies and change metrics port (#162)
  * fix typo (#161)
  * updating CRD apiversion to v1 (#156)
  * Add brief design doc (#150)
  * delete vendor folder and dep files (#147)
  * Bump sigs.k8s.io/controller-runtime from 0.6.2 to 0.6.3 (#146)
  * Bump sigs.k8s.io/controller-runtime from 0.6.0 to 0.6.2 (#142)
  * Enable all known auth methods (#143)
  * update all.yaml to use recent v0.9.4 release (#140)
  * Update x/text to 0.3.3 for CVE (#139)
* Fri Feb 26 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 0.9.4
  - Fix case where rbac-manager doesn't handle the namespace
    that does not exist and is later created
  - Fix case where rules for non-existing namespaces will be
    ignored forever
  - Bump sigs.k8s.io/controller-runtime from 0.5.1 to 0.5.2
  - Bump sigs.k8s.io/controller-runtime from 0.5.2 to 0.6.0
  - Update x/text to 0.3.3 for CVE
  - update yaml manifest to v0.9.2
  - Bump sigs.k8s.io/controller-runtime from 0.1.11 to 0.5.1
  - using numeric user in Dockerfile for PSP
* Tue Mar  3 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.2
  - Fixes major bug which will cause deletion and re-creation of
    a service account
* Tue Feb 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.1
  - Fix klog flag usage
- Remove unused vendor.tar.gz source
* Wed Nov  6 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.9.0
  - You can now specify service account image pull secrets
  - Versioning now happens automagically.
* Sun Oct 27 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.4
  - bump sigs.k8s.io/controller-runtime to 0.3.0
  - Added a metrics endpoint
- vendor.tar.gz: update
- Use official kubic image in k8s.yaml file
* Mon Sep 30 2019 Jan Engelhardt <jengelh@inai.de>
- Use modern tar options.
* Fri Sep 27 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.3
  - Added mutex to prevent reconciler loops from overlapping.
* Mon Sep 16 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.8.2
  - Reverted breaking label selector change.
  - Corrected version in log output
* Sun Jul 21 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to rbac-manager 0.8.0
  - detecting changes to role bindings owned by RBAC Definitions
    and repairing to desired state (#52)
  - initial work on watching resources owned by rbac definitions
  - improved reconciliation logic mostly working, better tests still needed
  - back to controller-runtime for namespace
* Thu May 23 2019 Thorsten Kukuk <kukuk@suse.com>
- Initial version
